==> ejc-cost-api-3.0.0-20250206.013004-430-sources.jar: com/ejianc/business/budget/api/IBudgetProjectProApi.java <==
package com.ejianc.business.budget.api;

import com.ejianc.business.budget.hystrix.BudgetProjectProHystrix;
import com.ejianc.business.budget.vo.BudgetProjectProParamControlVO;
import com.ejianc.business.budget.vo.BudgetProjectProQuantityAndMnyVO;
import com.ejianc.framework.core.response.CommonResponse;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestParam;

import java.math.BigDecimal;
import java.util.List;
import java.util.Map;

/**
 * 项目预算API接口
 *
 * @author baipengyan
 * @version 1.0
 * @since JDK 1.8
 */
@FeignClient(name = "ejc-cost-web", url = "${common.env.feign-client-url}", path = "ejc-cost-web", fallback = BudgetProjectProHystrix.class)
public interface IBudgetProjectProApi {

	/**
	 * 获取预算量价
	 *
	 * @param paramControlVO 项目预算Pro参数控制VO
	 *
	 * @return {@link CommonResponse}<{@link BudgetProjectProQuantityAndMnyVO}>
	 */
	@PostMapping(value = "/api/budgetProjectPro/fetchQuantityAndMny")
	CommonResponse<BudgetProjectProQuantityAndMnyVO> fetchQuantityAndMny(@Validated @RequestBody BudgetProjectProParamControlVO paramControlVO);

	/**
	 * 根据项目id查询该项目的预算编制单中 物资档案的预算总量
	 * @param projectId
	 * @return
	 */
	@GetMapping(value = "/api/budgetProjectPro/getBudgetProjectProQuantityByProjectId")
	public CommonResponse<Map<Long, BigDecimal>> getBudgetProjectProQuantityByProjectId(@RequestParam(value = "projectId", required = true) Long projectId);


	/**
	 * 获取预算金额
	 *
	 * @return {@link CommonResponse}<{@link BudgetProjectProQuantityAndMnyVO}>
	 */
	@PostMapping(value = "/api/budgetProjectPro/fetchBudgetMny")
	CommonResponse<BudgetProjectProQuantityAndMnyVO> fetchBudgetMny(@RequestBody List<Long> orgIds);

	/**
	 * 根据项目id查询该项目的总支出金额
	 * @param projectId
	 * @return
	 */
	@GetMapping(value = "/api/budgetProjectPro/getProOutMny")
	public CommonResponse<Map<String, BigDecimal>> getProOutMny(@RequestParam(value = "projectId") Long projectId,@RequestParam(value = "id") Long id,@RequestParam(value = "billTypeCode") String billTypeCode);
}

==> ejc-cost-api-3.0.0-20250512.080552-453-sources.jar: com/ejianc/business/budget/api/IBudgetProjectProApi.java <==
package com.ejianc.business.budget.api;

import com.ejianc.business.budget.hystrix.BudgetProjectProHystrix;
import com.ejianc.business.budget.vo.BudgetProjectProParamControlVO;
import com.ejianc.business.budget.vo.BudgetProjectProQuantityAndMnyVO;
import com.ejianc.framework.core.response.CommonResponse;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestParam;

import java.math.BigDecimal;
import java.util.List;
import java.util.Map;

/**
 * 项目预算API接口
 *
 * @author baipengyan
 * @version 1.0
 * @since JDK 1.8
 */
@FeignClient(name = "ejc-cost-web", url = "${common.env.feign-client-url}", path = "ejc-cost-web", fallback = BudgetProjectProHystrix.class)
public interface IBudgetProjectProApi {

	/**
	 * 获取预算量价
	 *
	 * @param paramControlVO 项目预算Pro参数控制VO
	 *
	 * @return {@link CommonResponse}<{@link BudgetProjectProQuantityAndMnyVO}>
	 */
	@PostMapping(value = "/api/budgetProjectPro/fetchQuantityAndMny")
	CommonResponse<BudgetProjectProQuantityAndMnyVO> fetchQuantityAndMny(@Validated @RequestBody BudgetProjectProParamControlVO paramControlVO);

	/**
	 * 根据项目id查询该项目的预算编制单中 物资档案的预算总量
	 * @param projectId
	 * @return
	 */
	@GetMapping(value = "/api/budgetProjectPro/getBudgetProjectProQuantityByProjectId")
	public CommonResponse<Map<Long, BigDecimal>> getBudgetProjectProQuantityByProjectId(@RequestParam(value = "projectId", required = true) Long projectId);


	/**
	 * 获取预算金额
	 *
	 * @return {@link CommonResponse}<{@link BudgetProjectProQuantityAndMnyVO}>
	 */
	@PostMapping(value = "/api/budgetProjectPro/fetchBudgetMny")
	CommonResponse<BudgetProjectProQuantityAndMnyVO> fetchBudgetMny(@RequestBody List<Long> orgIds);

	/**
	 * 根据项目id查询该项目的总支出金额
	 * @param projectId
	 * @return
	 */
	@GetMapping(value = "/api/budgetProjectPro/getProOutMny")
	public CommonResponse<Map<String, BigDecimal>> getProOutMny(@RequestParam(value = "projectId") Long projectId,@RequestParam(value = "id",required = false) Long id,@RequestParam(value = "billTypeCode") String billTypeCode);
}
